==> com.liferay.site.cms.site.initializer-1.0.5.jar: META-INF/resources/js/main/categorization/vocabularies/EditGeneralInfo.tsx <==
/**
 * SPDX-FileCopyrightText: (c) 2000 Liferay, Inc. https://liferay.com
 * SPDX-License-Identifier: LGPL-2.1-or-later OR LicenseRef-Liferay-DXP-EULA-2.0.0-2023-06
 */

import ClayAlert from '@clayui/alert';
import {LanguagePicker, Provider} from '@clayui/core';
import ClayForm, {
	ClayInput,
	ClaySelectWithOption,
	ClayToggle,
} from '@clayui/form';
import ClayIcon from '@clayui/icon';
import {ClayTooltipProvider} from '@clayui/tooltip';
import {sub} from 'frontend-js-web';
import React, {useState} from 'react';

import CategorizationSpaces from '../components/CategorizationSpaces';
import {IVocabulary} from '../types/IVocabulary';

const VISIBILITY_OPTIONS = [
	{
		label: Liferay.Language.get('public'),
		value: 0,
	},
	{
		label: Liferay.Language.get('private'),
		value: 1,
	},
];

export default function EditGeneralInfo({
	defaultLanguageId,
	locales,
	nameInputError,
	onChangeVocabulary,
	setNameInputError,
	spritemap,
	vocabulary,
}: {
	defaultLanguageId: string;
	locales: any[];
	nameInputError: string;
	onChangeVocabulary: Function;
	setNameInputError: Function;
	spritemap: string;
	vocabulary: IVocabulary;
}) {
	const [languageId, setLanguageId] = useState<string>(defaultLanguageId);
	const [toggled, setToggle] = useState<boolean>(true);

	const getLanguageLabel = (languageId: string) => {
		return languageId.replace('_', '-');
	};

	const onChangeDescription = (newDescription: string) => {
		onChangeVocabulary(() => ({
			...vocabulary,
			...(languageId === defaultLanguageId && {
				description: newDescription,
			}),
			description_i18n: {
				...vocabulary.description_i18n,
				[getLanguageLabel(languageId)]: newDescription,
			},
		}));
	};

	const onChangeName = (newName: string) => {
		if (newName) {
			setNameInputError('');
		}
		else {
			setNameInputError(
				sub(
					Liferay.Language.get('the-x-field-is-required'),
					Liferay.Language.get('name')
				)
			);
		}

		onChangeVocabulary(() => ({
			...vocabulary,
			...(languageId === defaultLanguageId && {name: newName}),
			name_i18n: {
				...vocabulary.name_i18n,
				[getLanguageLabel(languageId)]: newName,
			},
		}));
	};

	return (
		<div className="vertical-nav-content-wrapper">
			<ClayForm.Group className="c-gap-4 d-flex flex-column p-4">
				<div className="d-flex">
					<div className="autofit-col autofit-col-expand form-title">
						{Liferay.Language.get('basic-info')}
					</div>

					<div className="autofit-col" style={{width: 'fit-content'}}>
						<Provider spritemap={spritemap}>
							<LanguagePicker
								defaultLocaleId={defaultLanguageId}
								locales={locales}
								onSelectedLocaleChange={(
									localId: React.Key
								) => {
									setLanguageId(localId as string);
								}}
								selectedLocaleId={languageId}
								small
							/>
						</Provider>
					</div>
				</div>

				<div className={nameInputError ? 'has-error' : ''}>
					<label>
						{Liferay.Language.get('name')}

						<ClayIcon
							className="c-ml-1 reference-mark"
							focusable="false"
							role="presentation"
							symbol="asterisk"
						/>
					</label>

					<ClayInput
						id={Liferay.Language.get('name')}
						onChange={({target: {value}}) => onChangeName(value)}
						required
						type="text"
						value={
							vocabulary.name_i18n[
								getLanguageLabel(languageId)
							] || ''
						}
					/>

					{nameInputError && (
						<ClayAlert displayType="danger" variant="feedback">
							{nameInputError}
						</ClayAlert>
					)}
				</div>

				<div>
					<label>{Liferay.Language.get('description')}</label>

					<ClayInput
						component="textarea"
						onChange={({target: {value}}) =>
							onChangeDescription(value)
						}
						type="text"
						value={
							vocabulary.description_i18n
								? vocabulary.description_i18n[
										getLanguageLabel(languageId)
									] || ''
								: ''
						}
					/>
				</div>

				<label className="toggle-switch">
					<ClayToggle onToggle={setToggle} toggled={toggled} />

					{Liferay.Language.get('allow-multiple-categories')}

					<ClayTooltipProvider>
						<span
							className="help-text-icon ml-2"
							title={Liferay.Language.get('multi-valued-help')}
						>
							<ClayIcon symbol="question-circle-full" />
						</span>
					</ClayTooltipProvider>
				</label>

				<div>
					<label>
						{Liferay.Language.get('visibility')}

						<ClayTooltipProvider>
							<span
								className="help-text-icon ml-2"
								title={Liferay.Language.get('visibility-help')}
							>
								<ClayIcon symbol="question-circle-full" />
							</span>
						</ClayTooltipProvider>
					</label>

					<ClaySelectWithOption options={VISIBILITY_OPTIONS} />
				</div>
			</ClayForm.Group>

			<ClayForm.Group className="c-gap-4 d-flex flex-column p-4">
				<div className="form-title">
					{Liferay.Language.get('space')}
				</div>

				<CategorizationSpaces checkboxText="vocabulary" />
			</ClayForm.Group>
		</div>
	);
}

==> com.liferay.site.cms.site.initializer-1.0.6.jar: META-INF/resources/js/main/categorization/vocabularies/EditGeneralInfo.tsx <==
/**
 * SPDX-FileCopyrightText: (c) 2000 Liferay, Inc. https://liferay.com
 * SPDX-License-Identifier: LGPL-2.1-or-later OR LicenseRef-Liferay-DXP-EULA-2.0.0-2023-06
 */

import ClayAlert from '@clayui/alert';
import {LanguagePicker, Provider} from '@clayui/core';
import ClayForm, {
	ClayInput,
	ClaySelectWithOption,
	ClayToggle,
} from '@clayui/form';
import ClayIcon from '@clayui/icon';
import {ClayTooltipProvider} from '@clayui/tooltip';
import {sub} from 'frontend-js-web';
import React, {useState} from 'react';

import CategorizationSpaces from '../components/CategorizationSpaces';
import {IVocabulary} from '../types/IVocabulary';

const VISIBILITY_OPTIONS = [
	{
		label: Liferay.Language.get('public'),
		value: 0,
	},
	{
		label: Liferay.Language.get('private'),
		value: 1,
	},
];

export default function EditGeneralInfo({
	defaultLanguageId,
	locales,
	nameInputError,
	onChangeVocabulary,
	setNameInputError,
	setSpaceInputError,
	spritemap,
	vocabulary,
}: {
	defaultLanguageId: string;
	locales: any[];
	nameInputError: string;
	onChangeVocabulary: Function;
	setNameInputError: Function;
	setSpaceInputError: (value: string) => void;
	spritemap: string;
	vocabulary: IVocabulary;
}) {
	const [languageId, setLanguageId] = useState<string>(defaultLanguageId);
	const [toggled, setToggle] = useState<boolean>(true);
	const [selectedSpaces, setSelectedSpaces] = useState<string[]>([]);

	const assetLibraries = selectedSpaces.map((number) => ({
		id: number,
	}));

	const getLanguageLabel = (languageId: string) => {
		return languageId.replace('_', '-');
	};

	const onChangeDescription = (newDescription: string) => {
		onChangeVocabulary(() => ({
			...vocabulary,
			...(languageId === defaultLanguageId && {
				description: newDescription,
			}),
			description_i18n: {
				...vocabulary.description_i18n,
				[getLanguageLabel(languageId)]: newDescription,
			},
		}));
	};

	const onChangeName = (newName: string) => {
		if (newName) {
			setNameInputError('');
		}
		else {
			setNameInputError(
				sub(
					Liferay.Language.get('the-x-field-is-required'),
					Liferay.Language.get('name')
				)
			);
		}

		onChangeVocabulary(() => ({
			...vocabulary,
			...(languageId === defaultLanguageId && {
				name: newName,
				siteId: assetLibraries,
			}),
			name_i18n: {
				...vocabulary.name_i18n,
				[getLanguageLabel(languageId)]: newName,
			},
		}));
	};

	return (
		<div className="vertical-nav-content-wrapper">
			<ClayForm.Group className="c-gap-4 d-flex flex-column p-4">
				<div className="d-flex">
					<div className="autofit-col autofit-col-expand form-title">
						{Liferay.Language.get('basic-info')}
					</div>

					<div className="autofit-col" style={{width: 'fit-content'}}>
						<Provider spritemap={spritemap}>
							<LanguagePicker
								defaultLocaleId={defaultLanguageId}
								locales={locales}
								onSelectedLocaleChange={(
									localId: React.Key
								) => {
									setLanguageId(localId as string);
								}}
								selectedLocaleId={languageId}
								small
							/>
						</Provider>
					</div>
				</div>

				<div className={nameInputError ? 'has-error' : ''}>
					<label>
						{Liferay.Language.get('name')}

						<ClayIcon
							className="c-ml-1 reference-mark"
							focusable="false"
							role="presentation"
							symbol="asterisk"
						/>
					</label>

					<ClayInput
						aria-label={Liferay.Language.get('name')}
						onChange={({target: {value}}) => onChangeName(value)}
						required
						type="text"
						value={
							vocabulary.name_i18n[
								getLanguageLabel(languageId)
							] || ''
						}
					/>

					{nameInputError && (
						<ClayAlert displayType="danger" variant="feedback">
							{nameInputError}
						</ClayAlert>
					)}
				</div>

				<div>
					<label>{Liferay.Language.get('description')}</label>

					<ClayInput
						aria-label={Liferay.Language.get('description')}
						component="textarea"
						onChange={({target: {value}}) =>
							onChangeDescription(value)
						}
						type="text"
						value={
							vocabulary.description_i18n
								? vocabulary.description_i18n[
										getLanguageLabel(languageId)
									] || ''
								: ''
						}
					/>
				</div>

				<label className="toggle-switch">
					<ClayToggle
						aria-label="Multi Value"
						onToggle={setToggle}
						toggled={toggled}
					/>

					{Liferay.Language.get('allow-multiple-categories')}

					<ClayTooltipProvider>
						<span
							className="help-text-icon ml-2"
							title={Liferay.Language.get('multi-valued-help')}
						>
							<ClayIcon symbol="question-circle-full" />
						</span>
					</ClayTooltipProvider>
				</label>

				<div>
					<label>
						{Liferay.Language.get('visibility')}

						<ClayTooltipProvider>
							<span
								className="help-text-icon ml-2"
								title={Liferay.Language.get('visibility-help')}
							>
								<ClayIcon symbol="question-circle-full" />
							</span>
						</ClayTooltipProvider>
					</label>

					<ClaySelectWithOption
						aria-label={Liferay.Language.get('visibility')}
						options={VISIBILITY_OPTIONS}
					/>
				</div>
			</ClayForm.Group>

			<ClayForm.Group className="c-gap-4 d-flex flex-column p-4">
				<div className="form-title">
					{Liferay.Language.get('space')}
				</div>

				<CategorizationSpaces
					checkboxText="vocabulary"
					setSelectedSpaces={setSelectedSpaces}
					setSpaceInputError={setSpaceInputError}
				/>
			</ClayForm.Group>
		</div>
	);
}
